@@ -1,4 +1,5 @@
 import logging
+
 from urllib.parse import urlencode
 
 # import pyximport
@@ -10,6 +11,7 @@ from ...utils import get_session_key, set_session_key
 from ...permissions import is_staff
 from ... import app_settings
 from ..devices.utils import get_request_device
+
 from .models import Passepartout
 from .functions import get_next_bump
 
@@ -17,7 +19,7 @@ logger = logging.getLogger('django_sso_app.core.apps.passepartout')
 
 
 def get_passepartout_login_redirect_url(request):
-    if is_staff(request.user):
+    if request.user.is_superuser:
         return None
 
     if app_settings.PASSEPARTOUT_PROCESS_ENABLED:
