@@ -1,7 +1,7 @@
 from django.conf.urls import url
 from rest_framework.urlpatterns import format_suffix_patterns
 
-from .views import ServiceApiViewSet, SubscriptionApiViewSet
+from .views import ServiceApiViewSet, SubscriptionApiViewSet, ServiceSubscriptionApiViewSet
 
 
 _service__urlpatterns = [
@@ -13,11 +13,11 @@ _service__urlpatterns = [
         name='detail'),
 
     url(r'^(?P<pk>\d+)/subscribe/$',
-        ServiceApiViewSet.as_view({'post': 'subscribe'}),
+        ServiceSubscriptionApiViewSet.as_view({'post': 'subscribe'}),
         name='subscription'),
 
     url(r'^(?P<pk>\d+)/unsubscribe/$',
-        ServiceApiViewSet.as_view({'post': 'unsubscribe'}),
+        ServiceSubscriptionApiViewSet.as_view({'post': 'unsubscribe'}),
         name='unsubscription'),
 ]
 
