@@ -21,11 +21,11 @@ from rest_framework import permissions
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-from allauth.account.models import EmailAddress
-
 from .serializers import (CheckUserExistenceSerializer,
                           UserSerializer, NewUserSerializer,
                           UserRevisionSerializer)
+
+from ...apps.emails.models import EmailAddress
 from ...permissions import StaffPermission
 from ...permissions import is_staff
 from ...utils import is_test_user, invalidate_cookie, get_session_key
@@ -209,7 +209,7 @@ class UserRevisionsApiView(generics.ListAPIView):
     User revisions entrypoint
     """
 
-    queryset = User.objects.filter(is_superuser=False)
+    queryset = User.objects.filter(is_superuser=False, is_staff=False)
     serializer_class = UserRevisionSerializer
     permission_classes = (StaffPermission,)
 
